.. WeJAX documentation master file, created by
   sphinx-quickstart on Wed Jan  8 16:34:00 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

WeJAX documentation
===================

Compute the Fisher Information Matrix (FIM) of your favorite models using
their Jacobians; take advantage of automatic differentiation if your model
is implemented in JAX to switly compute the Jacobian, or evaluate it
numerically with finite differences.

WeJAX also provide convenience fonctions to invert the FIM and compute error
bars and correlations on the estimated parameters, as well as nice-looking
plots.

In `Algonquian languages`_, a *wejack* is a species of American marten, a
carnivorous mammal native to North America and member of the mustelid family. It
is commonly known as a `fisher (Pekania pennanti)`_ in English. That makes it
the perfect mascot for our Fisher matrix package written in JAX!

.. _Algonquian languages: https://en.wikipedia.org/wiki/Algonquian_languages

.. _fisher (Pekania pennanti): https://en.wikipedia.org/wiki/Fisher_(animal)

.. image:: _static/img/wejax-light.svg
   :align: center
   :width: 70%
   :class: only-light

.. image:: _static/img/wejax-dark.svg
   :align: center
   :width: 70%
   :class: only-dark

.. toctree::
   :caption: Getting started
   :hidden:

   math
   examples_simple
   examples_gb
   examples_mbhb

.. toctree::
   :caption: Reference
   :hidden:

   jacobian
   fim
   errors
